@@ -1,6 +1,6 @@
 /*
    SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
-   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -20,10 +20,12 @@
 #include <QIcon>
 
 #include <KConfigGroup>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace PimCommon;
 
@@ -38,6 +40,11 @@ public:
     bool mHasAnnotation = false;
 };
 
+namespace
+{
+static const char myConfigAnnotationEditDialog[] = "AnnotationEditDialog";
+}
+
 AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *parent)
     : QDialog(parent)
     , d(new AnnotationEditDialogPrivate)
@@ -134,19 +141,17 @@ void AnnotationEditDialog::slotDeleteNote()
     }
 }
 
-void AnnotationEditDialog::readConfig()
-{
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "AnnotationEditDialog");
-    QSize size = group.readEntry("Size", QSize());
-    if (!size.isEmpty()) {
-        resize(size);
-    }
-}
-
 void AnnotationEditDialog::writeConfig()
 {
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "AnnotationEditDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigAnnotationEditDialog);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+}
+
+void AnnotationEditDialog::readConfig()
+{
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(400, 300));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myConfigAnnotationEditDialog);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
